@@ -11,8 +11,7 @@ class Provider:
         self.siteUrl = siteUrl
         self.language = ''
 
-        client.make_driver()
-        self.selenium = client.get_driver()
+        self.client = client.Client('http')
 
     def process_url(self, url):
         self.parsed_url = urlparse(url)
@@ -48,20 +47,24 @@ class Provider:
         """Gets cover data associated with a specific Manga."""
 
     def find_error(self, url):
-        logs = self.selenium._driver.get_log('performance')
-        status_code = utils.get_status(logs)
+        if self.client.is_selenium:
+            logs = self.client.selenium._driver.get_log('performance')
+            status_code = utils.get_status(logs)
+        else:
+            status_code = self.client.http.status_code
 
         http_error_msg = ""
 
-        if 400 <= status_code < 500:
-            http_error_msg = (
-                f"{status_code} Client Error for url: {url}"
-            )
+        if isinstance(status_code, int):
+            if 400 <= status_code < 500:
+                http_error_msg = (
+                    f"{status_code} Client Error for url: {url}"
+                )
 
-        elif 500 <= status_code < 600:
-            http_error_msg = (
-                f"{status_code} Server Error for url: {url}"
-            )
+            elif 500 <= status_code < 600:
+                http_error_msg = (
+                    f"{status_code} Server Error for url: {url}"
+                )
 
         if http_error_msg:
             raise HTTPError(url=url, code=status_code, msg=http_error_msg, hdrs=None, fp=None)
